@@ -243,6 +243,7 @@
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
 #define HAVE__LONGJMP 1
+#define HAVE_ARC4RANDOM_BUF 1
 #define HAVE_ATAN2L 1
 #define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
@@ -425,8 +426,9 @@
 #define DLEXT ".so"
 #define LIBDIR_BASENAME "lib"
 #define HAVE__SETJMP 1
-#define RUBY_SETJMP(env) __builtin_setjmp((env))
-#define RUBY_LONGJMP(env,val) __builtin_longjmp((env),val)
+#define RUBY_SETJMP(env) _setjmp((env))
+#define RUBY_LONGJMP(env,val) _longjmp((env),val)
+#define RUBY_JMP_BUF jmp_buf
 #define USE_MJIT 1
 #define HAVE_PTHREAD_H 1
 #define RUBY_PLATFORM "x86_64-linux"
